@@ -5,14 +5,23 @@ use warnings;
 
 use Carp;
 use Data::Dumper;
-use English qw(-no_match_chars);
+use English qw(-no_match_vars);
 use JSON qw(decode_json);
+use List::Util qw(none);
 
 use parent qw(Exporter);
 
-our @EXPORT_OK = qw( slurp slurp_json dump_json normalize_options);
+our @EXPORT_OK = qw( slurp slurp_json dump_json normalize_options dmp);
 
-our $VERSION = '0.0.9';
+our $VERSION = '1.0.3';
+
+########################################################################
+sub dmp {
+########################################################################
+  my (@args) = @_;
+
+  return Dumper( \@args );
+}
 
 ########################################################################
 sub slurp_json {
@@ -34,7 +43,7 @@ sub slurp {
 
   local $RS = undef;
 
-  open my $fh, '<', $file
+  open my $fh, '<:raw', $file
     or croak "ERROR: could not open $file\n";
 
   my $content = <$fh>;
@@ -70,4 +79,22 @@ sub dump_json {
   return JSON->new->pretty->encode($obj);
 }
 
+########################################################################
+sub args {
+########################################################################
+  my ( $args, @valid_keys ) = @_;
+
+  croak 'args(): first argument must be a hashref'
+    if ref($args) ne 'HASH';
+
+  my %ok  = map  { $_ => 1 } @valid_keys;
+  my @bad = grep { !$ok{$_} } keys %{$args};
+
+  croak sprintf 'bad argument(s): %s', join ', ', @bad
+    if @bad;
+
+  # return in the caller-specified order
+  return @{$args}{@valid_keys};
+}
+
 1;
